@@ -1,19 +1,18 @@
 from django.test import RequestFactory, TestCase
 from unittest.mock import patch
-from django.contrib.sessions.middleware import SessionMiddleware
 from django_appwrite.middleware import AppwriteMiddleware
 
 
 class AppwriteMiddlewareTestCase(TestCase):
     def setUp(self):
-        self.request_factory = RequestFactory()
-        self.middleware = AppwriteMiddleware(lambda x: x)
-        self.session_middleware = SessionMiddleware(lambda x: x)
+        self.factory = RequestFactory()
+        self.request = self.factory.get('/')
+        self.middleware = AppwriteMiddleware(self.request)
 
     def test_settings_attribute_error(self):
         with self.assertRaises(Exception) as context:
-            with self.settings(APPWRITE={}):
-                self.middleware = AppwriteMiddleware(lambda x: x)
+            with self.modify_settings(APPWRITE={}):
+                self.middleware = AppwriteMiddleware(self.request)
 
         self.assertIn("Make sure you have the following settings in your Django settings file", str(context.exception))
 
@@ -22,16 +21,16 @@ class AppwriteMiddlewareTestCase(TestCase):
         mock_get_user_info.return_value = {
             'email': 'test_user@example.com'
         }
-        request = self.request_factory.get('/')
-        request.META['USER_ID'] = 'test_user_id'
+        request = self.factory.get('/')
+        request.META['HTTP_USER_ID'] = 'test_user_id'
 
         response = self.middleware(request)
         self.assertEqual(response, request)
-        self.assertTrue(request.user.is_authenticated)
-        self.assertEqual(request.user.username, 'test_user@example.com')
+        self.assertTrue(response.user.is_authenticated)
+        self.assertEqual(response.user.username, 'test_user@example.com')
 
     def test_user_id_header_not_exists(self):
-        request = self.request_factory.get('/')
+        request = self.factory.get('/')
         response = self.middleware(request)
         self.assertEqual(response, request)
-        self.assertFalse(request.user.is_authenticated)
+        self.assertFalse(hasattr(response, 'user'))
